==> doxygen-docs-1.14.0-2-x86_64.pkg.tar.zst: usr/share/doc/doxygen/html/search/pages_c.js <==
var searchData=
[
  ['be_20done_0',['\todo { paragraph describing what is to be done }',['../commands.html#cmdtodo',1,'']]],
  ['be_20ignored_1',['\noop ( text to be ignored )',['../commands.html#cmdnoop',1,'']]],
  ['be_20shown_20as_20warning_2',['\raisewarning ( text to be shown as warning )',['../commands.html#cmdraisewarning',1,'']]],
  ['because_20scanner_20uses_20reject_3',['Help! I get the cryptic message &quot;input buffer overflow, can&apos;t enlarge buffer because scanner uses REJECT&quot;',['../faq.html#faq_lex',1,'']]],
  ['binaries_20on_20unix_4',['Installing the binaries on UNIX',['../install.html#install_bin_unix',1,'']]],
  ['binaries_20on_20windows_5',['Installing the binaries on Windows',['../install.html#install_bin_windows',1,'']]],
  ['block_6',['block',['../commands.html#cmdhtmlinclude',1,'\htmlinclude['[block]'] &lt;file-name&gt;'],['../commands.html#cmdhtmlonly',1,'\htmlonly['[block]']'],['../docblocks.html#docstructure',1,'Anatomy of a comment block']]],
  ['block_20indentation_7',['Code Block Indentation',['../markdown.html#mddox_code_blocks',1,'']]],
  ['block_20quotes_8',['Block quotes',['../markdown.html#md_blockquotes',1,'']]],
  ['block_5fid_9',['block_id',['../commands.html#cmdsnippet',1,'\snippet['{'option'}'] &lt;file-name&gt; ( block_id )'],['../commands.html#cmdsnippetdoc',1,'\snippetdoc['{'option'}'] &lt;file-name&gt; ( block_id )'],['../commands.html#cmdsnippetlineno',1,'\snippetlineno &lt;file-name&gt; ( block_id )']]],
  ['blocks_10',['Blocks',['../markdown.html#md_codeblock',1,'Code Blocks'],['../markdown.html#md_fenced',1,'Fenced Code Blocks']]],
  ['blocks_11',['blocks',['../docblocks.html#specialblock',1,'Special comment blocks'],['../markdown.html#md_html_blocks',1,'Treatment of HTML blocks']]],
  ['blocks_20for_20c_20like_20languages_20c_20c_20c_20objective_20c_20php_20java_12',['Comment blocks for C-like languages (C/C++/C#/Objective-C/PHP/Java)',['../docblocks.html#cppblock',1,'']]],
  ['blocks_20in_20fortran_13',['Comment blocks in Fortran',['../docblocks.html#fortranblocks',1,'']]],
  ['blocks_20in_20python_14',['Comment blocks in Python',['../docblocks.html#pythonblocks',1,'']]],
  ['blocks_20in_20vhdl_15',['Comment blocks in VHDL',['../docblocks.html#vhdlblocks',1,'']]],
  ['brief_20description_16',['\brief { brief description }',['../commands.html#cmdbrief',1,'']]],
  ['browsing_17',['Configuration options related to source browsing',['../config.html#config_source_browser',1,'']]],
  ['buffer_20because_20scanner_20uses_20reject_18',['Help! I get the cryptic message &quot;input buffer overflow, can&apos;t enlarge buffer because scanner uses REJECT&quot;',['../faq.html#faq_lex',1,'']]],
  ['buffer_20overflow_20can_20t_20enlarge_20buffer_20because_20scanner_20uses_20reject_19',['Help! I get the cryptic message &quot;input buffer overflow, can&apos;t enlarge buffer because scanner uses REJECT&quot;',['../faq.html#faq_lex',1,'']]],
  ['bug_20',['How to report a bug',['../trouble.html#bug_reports',1,'']]],
  ['bug_20description_21',['\bug { bug description }',['../commands.html#cmdbug',1,'']]],
  ['build_20related_20configuration_20options_22',['Build related configuration options',['../config.html#config_build',1,'']]]
];

==> doxygen-docs-1.15.0-2-x86_64.pkg.tar.zst: usr/share/doc/doxygen/html/search/pages_c.js <==
var searchData=
[
  ['be_20done_0',['\\todo { paragraph describing what is to be done }',['../commands.html#cmdtodo',1,'']]],
  ['be_20ignored_1',['\\noop ( text to be ignored )',['../commands.html#cmdnoop',1,'']]],
  ['be_20shown_20as_20warning_2',['\\raisewarning ( text to be shown as warning )',['../commands.html#cmdraisewarning',1,'']]],
  ['because_20scanner_20uses_20reject_3',['Help! I get the cryptic message &quot;input buffer overflow, can&apos;t enlarge buffer because scanner uses REJECT&quot;',['../faq.html#faq_lex',1,'']]],
  ['binaries_20on_20unix_4',['Installing the binaries on UNIX',['../install.html#install_bin_unix',1,'']]],
  ['binaries_20on_20windows_5',['Installing the binaries on Windows',['../install.html#install_bin_windows',1,'']]],
  ['block_6',['block',['../commands.html#cmdhtmlinclude',1,'\\htmlinclude[&apos;[block]&apos;] &amp;lt;file-name&amp;gt;'],['../commands.html#cmdhtmlonly',1,'\\htmlonly[&apos;[block]&apos;]'],['../docblocks.html#docstructure',1,'Anatomy of a comment block']]],
  ['block_20indentation_7',['Code Block Indentation',['../markdown.html#mddox_code_blocks',1,'']]],
  ['block_20quotes_8',['Block quotes',['../markdown.html#md_blockquotes',1,'']]],
  ['block_5fid_9',['block_id',['../commands.html#cmdsnippet',1,'\\snippet[&apos;{&apos;option&apos;}&apos;] &amp;lt;file-name&amp;gt; ( block_id )'],['../commands.html#cmdsnippetdoc',1,'\\snippetdoc[&apos;{&apos;option&apos;}&apos;] &amp;lt;file-name&amp;gt; ( block_id )'],['../commands.html#cmdsnippetlineno',1,'\\snippetlineno &amp;lt;file-name&amp;gt; ( block_id )']]],
  ['blocks_10',['Blocks',['../markdown.html#md_codeblock',1,'Code Blocks'],['../markdown.html#md_fenced',1,'Fenced Code Blocks']]],
  ['blocks_11',['blocks',['../docblocks.html#specialblock',1,'Special comment blocks'],['../markdown.html#md_html_blocks',1,'Treatment of HTML blocks']]],
  ['blocks_20for_20c_20like_20languages_20c_20c_20c_20objective_20c_20php_20java_12',['Comment blocks for C-like languages (C/C++/C#/Objective-C/PHP/Java)',['../docblocks.html#cppblock',1,'']]],
  ['blocks_20in_20fortran_13',['Comment blocks in Fortran',['../docblocks.html#fortranblocks',1,'']]],
  ['blocks_20in_20python_14',['Comment blocks in Python',['../docblocks.html#pythonblocks',1,'']]],
  ['blocks_20in_20vhdl_15',['Comment blocks in VHDL',['../docblocks.html#vhdlblocks',1,'']]],
  ['brief_20description_16',['\\brief { brief description }',['../commands.html#cmdbrief',1,'']]],
  ['browsing_17',['Configuration options related to source browsing',['../config.html#config_source_browser',1,'']]],
  ['buffer_20because_20scanner_20uses_20reject_18',['Help! I get the cryptic message &quot;input buffer overflow, can&apos;t enlarge buffer because scanner uses REJECT&quot;',['../faq.html#faq_lex',1,'']]],
  ['buffer_20overflow_20can_20t_20enlarge_20buffer_20because_20scanner_20uses_20reject_19',['Help! I get the cryptic message &quot;input buffer overflow, can&apos;t enlarge buffer because scanner uses REJECT&quot;',['../faq.html#faq_lex',1,'']]],
  ['bug_20',['How to report a bug',['../trouble.html#bug_reports',1,'']]],
  ['bug_20description_21',['\\bug { bug description }',['../commands.html#cmdbug',1,'']]],
  ['build_20related_20configuration_20options_22',['Build related configuration options',['../config.html#config_build',1,'']]]
];
